@@ -133,8 +133,7 @@ class Dictionary():
                     for x in self.words
                 ]
             for word in self.words:
-                if len(word) > self.max_word_len:
-                    self.max_word_len = len(word)
+                self.max_word_len = max(self.max_word_len, len(word))
             if DEBUG_LEVEL > 1:
                 LOGGER.debug(
                     'max_word_len = %s\n', self.max_word_len)
@@ -794,7 +793,7 @@ def main() -> None:
         profile.enable()
 
     import doctest # pylint: disable=import-outside-toplevel
-    (failed, dummy_attempted) = doctest.testmod()
+    (failed, _attempted, *_extras) = doctest.testmod()
 
     if BENCHMARK:
         profile.disable()
