@@ -27,6 +27,12 @@ from typing import Iterable
 from typing import Any
 import sys
 import ctypes
+from gi import require_version # type: ignore
+# pylint: disable=wrong-import-position
+require_version('IBus', '1.0')
+from gi.repository import IBus # type: ignore
+# pylint: enable=wrong-import-position
+import itb_util
 
 # pylint: disable=invalid-name
 # pylint: disable=too-few-public-methods
@@ -1045,7 +1051,10 @@ class Transliterator:
         except ValueError as error: # NULL pointer access
             raise ValueError('minput_create_ic() failed') from error
 
-    def transliterate_parts(self, msymbol_list: Iterable[str], ascii_digits: bool = False) -> Tuple[str, str]:
+    def transliterate_parts(
+            self,
+            msymbol_list: Iterable[str],
+            ascii_digits: bool = False) -> Tuple[str, str]:
         '''Transliterate a list of Msymbol names
 
         :param msymbol_list: A list of strings which are interpreted
@@ -1064,7 +1073,14 @@ class Transliterator:
         libm17n__minput_reset_ic(self._ic) # type: ignore
         committed = ''
         preedit = ''
-        for symbol in msymbol_list:
+        for index, symbol in enumerate(msymbol_list):
+            if len(symbol) == 1 and not itb_util.is_ascii(symbol):
+                symbol = IBus.keyval_name(IBus.unicode_to_keyval(symbol))
+            elif (len(symbol) == 3 and symbol[1] == '-'
+                and symbol[0] in ('G', 'C', 'A')
+                and not itb_util.is_ascii(symbol[2])):
+                symbol = symbol[:2] + IBus.keyval_name(
+                    IBus.unicode_to_keyval(symbol[2]))
             _symbol = libm17n__msymbol(symbol.encode('utf-8')) # type: ignore
             retval = libm17n__minput_filter( # type: ignore
                 self._ic, _symbol, ctypes.c_void_p(None))
@@ -1075,7 +1091,7 @@ class Transliterator:
                 if libm17n__mtext_len(_mt) > 0: # type: ignore
                     committed += mtext_to_string(_mt)
                 if retval:
-                    committed += symbol
+                    committed += msymbol_list[index]
         try:
             if (self._ic.contents.preedit_changed
                 and
@@ -1330,5 +1346,5 @@ class Transliterator:
 
 if __name__ == "__main__":
     import doctest
-    (FAILED, _ATTEMPTED) = doctest.testmod()
+    (FAILED, _ATTEMPTED, *_EXTRAS) = doctest.testmod()
     sys.exit(FAILED)
